@@ -3,19 +3,18 @@ BEGIN {
   $OX::Application::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $OX::Application::VERSION = '0.06';
+  $OX::Application::VERSION = '0.07';
 }
 use Moose 2.0200;
 use namespace::autoclean;
 # ABSTRACT: base class for OX applications
 
 use Bread::Board;
-use Moose::Util::TypeConstraints 'match_on_type';
 use Plack::Middleware::HTTPExceptions;
 use Plack::Util;
 use Try::Tiny;
 
-use OX::Types;
+use OX::Util;
 
 extends 'Bread::Board::Container';
 
@@ -79,20 +78,7 @@ sub BUILD {
                 );
 
                 for my $middleware (reverse @middleware) {
-                    match_on_type $middleware => (
-                        'CodeRef' => sub {
-                            $app = $middleware->($app);
-                        },
-                        'OX::Types::MiddlewareClass' => sub {
-                            $app = $middleware->wrap($app);
-                        },
-                        'Plack::Middleware' => sub {
-                            $app = $middleware->wrap($app);
-                        },
-                        sub {
-                            warn "not applying middleware $middleware!";
-                        },
-                    );
+                    $app = OX::Util::apply_middleware($app, $middleware);
                 }
 
                 $app;
@@ -152,7 +138,7 @@ OX::Application - base class for OX applications
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
